![Screenshot of ships in ATAK, via AISCOT.](https://aiscot.readthedocs.io/en/latest/media/aiscot_screenshot_tak_logo.png)

# Display Ships in TAK - AIS to TAK Gateway 

AISCOT is software for monitoring and analyzing maritime surveillance data within the 
Team Awareness KIT (TAK) suite of products.

AISCOT captures and reports real-time automatic identification system (AIS) data 
received from vessels (or other maritime objects) into TAK Products using native TAK 
protocols, including Cursor on Target (CoT).

AISCOT has been evaluated with ATAK, WinTAK, iTAK, TAK Server & TAKX, and is know to 
work with other situational awareness (SA) software.

AISCOT supports over-the-air radio (RF) AIS transmissions, local NMEA, and Internet 
AIS aggregators (like AISHUB). AIS data is displayed in TAK with appropriate icons, 
attitude, type, track, bearing, speed, callsign and more.

AISCOT was original developed to support an [open ocean boat race in the Northern 
Pacific Ocean](http://ampledata.org/boat_race_support.html).

[AISCOT documentation is available here.](https://aiscot.rtfd.io)

## License & Copyright

Copyright Sensors & Signals LLC https://www.snstac.com

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

* pyAISm.py is licensed under the MIT License. See aiscot/pyAISm.py for details.
